/***********************************************************************************************************************
* File Name    : lowlvl.c
* Device(s)    : RX
* H/W Platform : GR-SAKURA (RX63N)
* Description  : Functions to support stream I/O to the E1 virtual Console.
***********************************************************************************************************************/
/***********************************************************************************************************************
* History : DD.MM.YYYY Version  Description
*         : 10.07.2017 1.00     First Release
***********************************************************************************************************************/

/***********************************************************************************************************************
Includes   <System Includes> , "Project Includes"
***********************************************************************************************************************/
/* r_bsp access. */
#include "platform.h"

/***********************************************************************************************************************
Macro definitions
***********************************************************************************************************************/
#define E1_DBG_PORT (*(volatile struct st_dbg      *)0x84080)
#define TXFL0EN     0x00000100          // debug tx flow control bit
#define RXFL0EN     0x00001000          // debug RX flow control bit

/***********************************************************************************************************************
Typedef definitions
***********************************************************************************************************************/
struct st_dbg
{
    uint32_t   TX_DATA;     // Debug Virtual Console TX data
    char       wk1[12];     // spacer
    uint32_t   RX_DATA;     // Debug Virtual Console RX data
    char       wk2[44];     // spacer
    uint32_t   DBGSTAT;     // Debug Virtual Console Status
};

/***********************************************************************************************************************
Exported global variables (to be accessed by other files)
***********************************************************************************************************************/

/***********************************************************************************************************************
Private global variables and functions
***********************************************************************************************************************/

/***********************************************************************************************************************
* Function Name: charput
* Description  : Outputs a character on a serial port
* Arguments    : character to output
* Return Value : none
***********************************************************************************************************************/
void charput (uint32_t output_char)
{
	/* Wait for transmit buffer to be empty */
	while(0 != (E1_DBG_PORT.DBGSTAT & TXFL0EN));

	/* Write the character out */
	E1_DBG_PORT.TX_DATA = output_char;
}

/***********************************************************************************************************************
* Function Name: charget
* Description  : Gets a character on a serial port
* Arguments    : none
* Return Value : received character
***********************************************************************************************************************/
uint32_t charget (void)
{
	/* Wait for rx buffer buffer to be ready */
	while(0 == (E1_DBG_PORT.DBGSTAT & RXFL0EN));

	/* Read data, send back up */
	return E1_DBG_PORT.RX_DATA;
}

